FontIdentifier

Enum FontIdentifier 

pub enum FontIdentifier {
    ComputerModern(FontWeight),
}
An identifier for a font used in typst layouts.

Variants



ComputerModern(FontWeight)

Font data for Computer Modern font, which is the default font used in Layout::Aioo. It is not a default system font so we include it in the klirr binary.

Computer Modern is a family of typefaces designed by Donald Knuth for use in the TeX typesetting system. It is widely used in academic and scientific documents. The font is available under the SIL Open Font License, which allows for both personal and commercial use, as well as modification and redistribution.

Implementations

Source

impl FontIdentifier

pub fn family_name(&self) -> String

MUST match the family_name in the font definition, e.g. as shown in Fonts app on macOS.

pub fn font_bytes(&self) -> &'static [u8]

The raw bytes of the font data, can be used by Typst to load the font into a Typst::Font, used by the Typst typesetting engine, this allows us to vendor the font data directly in the binary.