pub enum Granularity {
Hour,
Day,
Fortnight,
Month,
}Expand description
The granularity of invoiced quantity, i.e. if you are invoicing fixed rate per month, per day or per hour.
Variants
Implementations
Sourceimpl Granularity
impl Granularity
Sourcepub const fn is_hour(&self) -> bool
pub const fn is_hour(&self) -> bool
Returns true if this value is of type Hour. Returns false otherwise
Sourcepub const fn is_day(&self) -> bool
pub const fn is_day(&self) -> bool
Returns true if this value is of type Day. Returns false otherwise
Sourcepub const fn is_fortnight(&self) -> bool
pub const fn is_fortnight(&self) -> bool
Returns true if this value is of type Fortnight. Returns false otherwise
Sourceimpl Granularity
impl Granularity
pub fn example_rate(&self) -> String