Weekday

Enum Weekday 

pub enum Weekday {
    Mon = 0,
    Tue = 1,
    Wed = 2,
    Thu = 3,
    Fri = 4,
    Sat = 5,
    Sun = 6,
}
The day of week.

The order of the days of week depends on the context. (This is why this type does not implement PartialOrd or Ord traits.) One should prefer *_from_monday or *_from_sunday methods to get the correct result.

Example

use chrono::Weekday;

let monday = "Monday".parse::<Weekday>().unwrap();
assert_eq!(monday, Weekday::Mon);

let sunday = Weekday::try_from(6).unwrap();
assert_eq!(sunday, Weekday::Sun);

assert_eq!(sunday.num_days_from_monday(), 6); // starts counting with Monday = 0
assert_eq!(sunday.number_from_monday(), 7); // starts counting with Monday = 1
assert_eq!(sunday.num_days_from_sunday(), 0); // starts counting with Sunday = 0
assert_eq!(sunday.number_from_sunday(), 1); // starts counting with Sunday = 1

assert_eq!(sunday.succ(), monday);
assert_eq!(sunday.pred(), Weekday::Sat);

Variants



Mon = 0

Monday.



Tue = 1

Tuesday.



Wed = 2

Wednesday.



Thu = 3

Thursday.



Fri = 4

Friday.



Sat = 5

Saturday.



Sun = 6

Sunday.

Implementations

Source

impl Weekday

pub const fn succ(&self) -> Weekday

The next day in the week.

w:MonTueWedThuFriSatSun
w.succ():TueWedThuFriSatSunMon
pub const fn pred(&self) -> Weekday

The previous day in the week.

w:MonTueWedThuFriSatSun
w.pred():SunMonTueWedThuFriSat
pub const fn number_from_monday(&self) -> u32

Returns a day-of-week number starting from Monday = 1. (ISO 8601 weekday number)

w:MonTueWedThuFriSatSun
w.number_from_monday():1234567
pub const fn number_from_sunday(&self) -> u32

Returns a day-of-week number starting from Sunday = 1.

w:MonTueWedThuFriSatSun
w.number_from_sunday():2345671
pub const fn num_days_from_monday(&self) -> u32

Returns a day-of-week number starting from Monday = 0.

w:MonTueWedThuFriSatSun
w.num_days_from_monday():0123456
Example
// MTWRFSU is occasionally used as a single-letter abbreviation of the weekdays.
// Use `num_days_from_monday` to index into the array.
const MTWRFSU: [char; 7] = ['M', 'T', 'W', 'R', 'F', 'S', 'U'];

let today = Local::now().weekday();
println!("{}", MTWRFSU[today.num_days_from_monday() as usize]);
pub const fn num_days_from_sunday(&self) -> u32

Returns a day-of-week number starting from Sunday = 0.

w:MonTueWedThuFriSatSun
w.num_days_from_sunday():1234560
pub const fn days_since(&self, other: Weekday) -> u32

The number of days since the given day.

Examples
use chrono::Weekday::*;
assert_eq!(Mon.days_since(Mon), 0);
assert_eq!(Sun.days_since(Tue), 5);
assert_eq!(Wed.days_since(Sun), 3);