pub struct DataFromDiskWithItemsOfKind<Items>where
Items: Serialize + MaybeIsExpenses,{ /* private fields */ }Expand description
The input data for the invoice, which includes information about the invoice, the vendor, and the client and the products/services included in the invoice.
Implementations
Sourceimpl<Items> DataFromDiskWithItemsOfKind<Items>where
Items: Serialize + MaybeIsExpenses,
impl<Items> DataFromDiskWithItemsOfKind<Items>where
Items: Serialize + MaybeIsExpenses,
Sourcepub fn builder() -> DataFromDiskWithItemsOfKindBuilder<Items>
pub fn builder() -> DataFromDiskWithItemsOfKindBuilder<Items>
Create an instance of DataFromDiskWithItemsOfKind using the builder syntax
Sourceimpl<Items> DataFromDiskWithItemsOfKind<Items>where
Items: Serialize + MaybeIsExpenses,
impl<Items> DataFromDiskWithItemsOfKind<Items>where
Items: Serialize + MaybeIsExpenses,
Sourcepub fn information(&self) -> &InvoiceInfoFull
pub fn information(&self) -> &InvoiceInfoFull
Information about this specific invoice.
Sourcepub fn vendor(&self) -> &CompanyInformation
pub fn vendor(&self) -> &CompanyInformation
The company that issued the invoice, the vendor/seller/supplier/issuer.
Sourcepub fn client(&self) -> &CompanyInformation
pub fn client(&self) -> &CompanyInformation
The company that pays the invoice, the customer/buyer.
Sourcepub fn line_items(&self) -> &Items
pub fn line_items(&self) -> &Items
Services or expenses included in this invoice to be paid by the client.
Sourcepub fn payment_info(&self) -> &PaymentInformation
pub fn payment_info(&self) -> &PaymentInformation
Payment information for the vendor, used for international transfers. This includes the IBAN, bank name, and BIC. This is used to ensure that the client can pay the invoice correctly.
Sourceimpl<Items> DataFromDiskWithItemsOfKind<Items>where
Items: Serialize + MaybeIsExpenses,
impl<Items> DataFromDiskWithItemsOfKind<Items>where
Items: Serialize + MaybeIsExpenses,
Sourcepub fn absolute_path_and_name(&self) -> Result<PathAndName, Error>
pub fn absolute_path_and_name(&self) -> Result<PathAndName, Error>
Returns the absolute path where the invoice will be saved. If the path is relative, it will be created relative to the workspace root. If the path is absolute, it will be returned as is.
Errors
Returns an error if the path is relative and the folder cannot be created, or if the path is absolute but invalid.
Examples
extern crate klirr_core;
use klirr_core::prelude::*;
let data = DataWithItemsPricedInSourceCurrency::builder()
.information(InvoiceInfoFull::sample())
.vendor(CompanyInformation::sample())
.client(CompanyInformation::sample())
.line_items(LineItemsPricedInSourceCurrency::sample())
.payment_info(PaymentInformation::sample())
.output_path(OutputPath::Name("invoice.pdf".into()))
.build();
let path_and_name = data.absolute_path_and_name().unwrap();
assert!(path_and_name.path().ends_with("invoice.pdf"));
assert_eq!(path_and_name.name(), "invoice.pdf");Sourceimpl DataFromDiskWithItemsOfKind<LineItemsPricedInSourceCurrency>
impl DataFromDiskWithItemsOfKind<LineItemsPricedInSourceCurrency>
Sourcepub fn to_typst(
self,
exchange_rates: ExchangeRates,
) -> Result<DataFromDiskWithItemsOfKind<LineItemsFlat>, Error>
pub fn to_typst( self, exchange_rates: ExchangeRates, ) -> Result<DataFromDiskWithItemsOfKind<LineItemsFlat>, Error>
Converts the DataWithItemsPricedInSourceCurrency into a PreparedData
which is compatible with Typst rendering.
This method prepares the invoice data for rendering by creating an
ExchangeRates object and converting the line items into a flat structure.
Errors
Returns an error if the line items cannot be converted to a flat structure.
Examples
extern crate klirr_core;
use klirr_core::prelude::*;
let data = DataWithItemsPricedInSourceCurrency::sample();
let exchange_rates = ExchangeRates::builder().rates(ExchangeRatesMap::from_iter([(Currency::GBP, UnitPrice::from(dec!(10.0))), (Currency::EUR, UnitPrice::from(dec!(8.0)))])).target_currency(Currency::EUR).build();
let result = data.to_typst(exchange_rates);
assert!(result.is_ok(), "Expected conversion to succeed, got: {:?}", result);Trait Implementations
Sourceimpl<Items> Clone for DataFromDiskWithItemsOfKind<Items>
impl<Items> Clone for DataFromDiskWithItemsOfKind<Items>
Sourcefn clone(&self) -> DataFromDiskWithItemsOfKind<Items>
fn clone(&self) -> DataFromDiskWithItemsOfKind<Items>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<Items> Debug for DataFromDiskWithItemsOfKind<Items>
impl<Items> Debug for DataFromDiskWithItemsOfKind<Items>
Sourceimpl<'de, Items> Deserialize<'de> for DataFromDiskWithItemsOfKind<Items>
impl<'de, Items> Deserialize<'de> for DataFromDiskWithItemsOfKind<Items>
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<DataFromDiskWithItemsOfKind<Items>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<DataFromDiskWithItemsOfKind<Items>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
impl<Items> Eq for DataFromDiskWithItemsOfKind<Items>
Sourceimpl<Items> HasSample for DataFromDiskWithItemsOfKind<Items>
impl<Items> HasSample for DataFromDiskWithItemsOfKind<Items>
Sourcefn sample() -> DataFromDiskWithItemsOfKind<Items>
fn sample() -> DataFromDiskWithItemsOfKind<Items>
fn sample_other() -> DataFromDiskWithItemsOfKind<Items>
Sourceimpl<Items> Hash for DataFromDiskWithItemsOfKind<Items>
impl<Items> Hash for DataFromDiskWithItemsOfKind<Items>
Sourceimpl<Items> PartialEq for DataFromDiskWithItemsOfKind<Items>
impl<Items> PartialEq for DataFromDiskWithItemsOfKind<Items>
Sourcefn eq(&self, other: &DataFromDiskWithItemsOfKind<Items>) -> bool
fn eq(&self, other: &DataFromDiskWithItemsOfKind<Items>) -> bool
self and other values to be equal, and is used by ==.Sourceimpl<Items> Serialize for DataFromDiskWithItemsOfKind<Items>where
Items: Serialize + MaybeIsExpenses,
impl<Items> Serialize for DataFromDiskWithItemsOfKind<Items>where
Items: Serialize + MaybeIsExpenses,
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl<Items> StructuralPartialEq for DataFromDiskWithItemsOfKind<Items>where
Items: Serialize + MaybeIsExpenses,
impl ToTypst for DataFromDiskWithItemsOfKind<LineItemsFlat>