pub struct InvoiceInfoFull { /* private fields */ }Expand description
A full invoice information structure that includes the derived
invoice number, invoice date, due date and other
details from the ProtoInvoiceInfo.
Implementations
Sourceimpl InvoiceInfoFull
impl InvoiceInfoFull
Sourcepub fn number(&self) -> &InvoiceNumber
pub fn number(&self) -> &InvoiceNumber
The unique number of this invoice, typically a number, e.g. "90"
Sourcepub fn invoice_date(&self) -> &Date
pub fn invoice_date(&self) -> &Date
When the payment is due, calculated from the invoice date and payment terms.
Sourcepub fn due_date(&self) -> &Date
pub fn due_date(&self) -> &Date
When the payment is due, calculated from the invoice date and payment terms.
Sourcepub fn purchase_order(&self) -> &Option<PurchaseOrder>
pub fn purchase_order(&self) -> &Option<PurchaseOrder>
A purchase order number associated with this invoice, e.g. "PO-12345"
Typically agreed upon between the vendor and client before the
invoice is issued.
E.g. “Reverse VAT according to chapter 1 2 first section 4b in the VAT regulation.”
Sourcepub fn emphasize_color_hex(&self) -> &HexColor
pub fn emphasize_color_hex(&self) -> &HexColor
Hex color code for the color emphasis of the invoice, e.g. "#e6007a".
Sourceimpl InvoiceInfoFull
impl InvoiceInfoFull
Sourcepub fn builder() -> InvoiceInfoFullBuilder
pub fn builder() -> InvoiceInfoFullBuilder
Create an instance of InvoiceInfoFull using the builder syntax