Local

Struct Local 

pub struct Local;
The local timescale.

Using the TimeZone methods on the Local struct is the preferred way to construct DateTime<Local> instances.

Example

use chrono::{DateTime, Local, TimeZone};

let dt1: DateTime<Local> = Local::now();
let dt2: DateTime<Local> = Local.timestamp_opt(0, 0).unwrap();
assert!(dt1 >= dt2);

Implementations

Source

impl Local

pub fn today() -> Date<Local>

👎Deprecated since 0.4.23:

use Local::now() instead

Returns a Date which corresponds to the current date.

pub fn now() -> DateTime<Local>

Returns a DateTime<Local> which corresponds to the current date, time and offset from UTC.

See also the similar Utc::now() which returns DateTime<Utc>, i.e. without the local offset.

Example
// Current local time
let now = Local::now();

// Current local date
let today = now.date_naive();

// Current local time, converted to `DateTime<FixedOffset>`
let now_fixed_offset = Local::now().fixed_offset();
// or
let now_fixed_offset: DateTime<FixedOffset> = Local::now().into();

// Current time in some timezone (let's use +05:00)
// Note that it is usually more efficient to use `Utc::now` for this use case.
let offset = FixedOffset::east_opt(5 * 60 * 60).unwrap();
let now_with_offset = Local::now().with_timezone(&offset);