pub struct ProtoInvoiceInfo<Period>where
Period: IsPeriod,{ /* private fields */ }Expand description
Partial information about the invoice which can be used to derive a InvoiceInfoFull
Implementations
Sourceimpl<Period> ProtoInvoiceInfo<Period>where
Period: IsPeriod,
impl<Period> ProtoInvoiceInfo<Period>where
Period: IsPeriod,
Sourcepub fn builder() -> ProtoInvoiceInfoBuilder<Period>
pub fn builder() -> ProtoInvoiceInfoBuilder<Period>
Create an instance of ProtoInvoiceInfo using the builder syntax
Sourceimpl<Period> ProtoInvoiceInfo<Period>where
Period: IsPeriod,
impl<Period> ProtoInvoiceInfo<Period>where
Period: IsPeriod,
Sourcepub fn offset(&self) -> &TimestampedInvoiceNumber<Period>
pub fn offset(&self) -> &TimestampedInvoiceNumber<Period>
An offset which is used to calculate the invoice number, e.g. (237, 2025-05).
This is enables us to calculate the next invoice number based on the current
date and this offset.
Sourcepub fn record_of_periods_off(&self) -> &RecordOfPeriodsOff<Period>
pub fn record_of_periods_off(&self) -> &RecordOfPeriodsOff<Period>
Record of periods when we were 100% off, i.e. did not invoice for, e.g. ["2025-01", "2025-02"].
Sourcepub fn purchase_order(&self) -> &Option<PurchaseOrder>
pub fn purchase_order(&self) -> &Option<PurchaseOrder>
A purchase order number associated with this invoice, e.g. "PO-12345"
Typically agreed upon between the vendor and client before the
invoice is issued.
E.g. “Reverse VAT according to chapter 1 2 first section 4b in the VAT regulation.”
Sourcepub fn emphasize_color_hex(&self) -> &Option<HexColor>
pub fn emphasize_color_hex(&self) -> &Option<HexColor>
Hex color code for the color emphasis of the invoice, e.g. "#e6007a".
Sourceimpl<Period> ProtoInvoiceInfo<Period>where
Period: IsPeriod,
impl<Period> ProtoInvoiceInfo<Period>where
Period: IsPeriod,
Sourcepub fn set_record_of_periods_off(
&mut self,
val: RecordOfPeriodsOff<Period>,
) -> &mut ProtoInvoiceInfo<Period>
pub fn set_record_of_periods_off( &mut self, val: RecordOfPeriodsOff<Period>, ) -> &mut ProtoInvoiceInfo<Period>
Record of periods when we were 100% off, i.e. did not invoice for, e.g. ["2025-01", "2025-02"].
Sourceimpl<Period> ProtoInvoiceInfo<Period>where
Period: IsPeriod,
impl<Period> ProtoInvoiceInfo<Period>where
Period: IsPeriod,
Sourcepub fn insert_period_off(&mut self, period: Period)
pub fn insert_period_off(&mut self, period: Period)
Inserts a new month into the months off record. This is used to keep track of months when no invoices were issued.
Examples
extern crate klirr_core;
use klirr_core::prelude::*;
let mut invoice_info = ProtoInvoiceInfo::<YearAndMonth>::sample();
let month = YearAndMonth::may(2025);
invoice_info.insert_period_off(month);
assert!(invoice_info.record_of_periods_off().contains(&month));Sourceimpl<Period> ProtoInvoiceInfo<Period>where
Period: IsPeriod,
impl<Period> ProtoInvoiceInfo<Period>where
Period: IsPeriod,
Sourcepub fn validate(&self) -> Result<(), Error>
pub fn validate(&self) -> Result<(), Error>
Validates the invoice information, ensuring that the offset month is not in the record of months off.
Examples
extern crate klirr_core;
use klirr_core::prelude::*;
let invoice_info = ProtoInvoiceInfo::<YearAndMonth>::sample();
assert!(invoice_info.validate().is_ok());Trait Implementations
Sourceimpl<Period> Clone for ProtoInvoiceInfo<Period>
impl<Period> Clone for ProtoInvoiceInfo<Period>
Sourcefn clone(&self) -> ProtoInvoiceInfo<Period>
fn clone(&self) -> ProtoInvoiceInfo<Period>
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl<Period> Debug for ProtoInvoiceInfo<Period>
impl<Period> Debug for ProtoInvoiceInfo<Period>
Sourceimpl<'de, Period> Deserialize<'de> for ProtoInvoiceInfo<Period>where
Period: IsPeriod + Deserialize<'de>,
impl<'de, Period> Deserialize<'de> for ProtoInvoiceInfo<Period>where
Period: IsPeriod + Deserialize<'de>,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<ProtoInvoiceInfo<Period>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<ProtoInvoiceInfo<Period>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl<Period> HasSample for ProtoInvoiceInfo<Period>
impl<Period> HasSample for ProtoInvoiceInfo<Period>
Sourcefn sample() -> ProtoInvoiceInfo<Period>
fn sample() -> ProtoInvoiceInfo<Period>
fn sample_other() -> ProtoInvoiceInfo<Period>
Sourceimpl<Period> PartialEq for ProtoInvoiceInfo<Period>
impl<Period> PartialEq for ProtoInvoiceInfo<Period>
Sourcefn eq(&self, other: &ProtoInvoiceInfo<Period>) -> bool
fn eq(&self, other: &ProtoInvoiceInfo<Period>) -> bool
self and other values to be equal, and is used by ==.Sourceimpl<Period> Serialize for ProtoInvoiceInfo<Period>
impl<Period> Serialize for ProtoInvoiceInfo<Period>
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl<Period> StructuralPartialEq for ProtoInvoiceInfo<Period>where
Period: IsPeriod,