Salt

Struct Salt 

pub struct Salt(/* private fields */);
A cryptographically secure random salt used for key derivation. It is used to ensure that the derived keys are unique even if the input key material is the same.

Implementations

Source

impl Salt

pub fn generate() -> Salt

Uses CSPRNG (safe) to generate a salt.