pub struct ValidInput { /* private fields */ }Expand description
Input which has been validated and is ready for processing. Controls which language to use, the month for which to generate the invoice, the items to be invoiced, the layout of the invoice, and an optional output path for the generated PDF file.
Implementations
Sourceimpl ValidInput
impl ValidInput
Sourcepub fn builder() -> ValidInputBuilder
pub fn builder() -> ValidInputBuilder
Create an instance of ValidInput using the builder syntax
Sourceimpl ValidInput
impl ValidInput
Sourcepub fn language(&self) -> &Language
pub fn language(&self) -> &Language
The language to use for the invoice, used on labels, headers etc.
Defaults to English (Language::EN).
Sourcepub fn period(&self) -> &YearMonthAndFortnight
pub fn period(&self) -> &YearMonthAndFortnight
The period for which to generate the invoice, this affects the invoice number as well as the invoice date and due date.
Note: We use the period type with the highest granularity, so that we
always can convert it to a kind of period of more coarse granularity.
For example, if the period is YearMonthAndFortnight, we can always
convert it to YearAndMonth later in the flow if that matches the invoice
cadence.
Sourcepub fn items(&self) -> &InvoicedItems
pub fn items(&self) -> &InvoicedItems
The items to be invoiced, either services or expenses.
Sourcepub fn maybe_output_path(&self) -> &Option<PathBuf>
pub fn maybe_output_path(&self) -> &Option<PathBuf>
An optional override of where to save the output PDF file.