Error

Enum Error 

pub enum Error {
Show 62 variants RecordsOffMustNotContainOffsetPeriod { offset_period: String, }, StartPeriodAfterEndPeriod { start: String, end: String, }, InvalidPeriod { bad_value: String, }, PeriodIsNotYearAndMonth, PeriodIsNotYearMonthAndFortnight, InvalidGranularityForTimeOff { free_granularity: Granularity, service_fees_granularity: Granularity, }, GranularityTooCoarse { granularity: Granularity, max_granularity: Granularity, target_period: String, }, CannotInvoiceForMonthWhenCadenceIsBiWeekly, CannotExpenseForMonthWhenCadenceIsBiWeekly, CannotExpenseForFortnightWhenCadenceIsMonthly, PasswordDoesNotMatch, EmailPasswordTooShort { min_length: usize, actual_length: usize, }, EmailAtomTemplateError { underlying: String, }, InvalidEmailAddress { role: String, underlying: String, }, InvalidNameForEmail { role: String, underlying: String, }, InvalidPasswordForEmail { purpose: String, underlying: String, }, RecipientAddressesCannotBeEmpty, InvalidSmtpServer { underlying: String, }, InvalidUtf8, AESDecryptionFailed, InvalidAESBytesTooShort { expected_at_least: usize, found: usize, }, CreateSmtpTransportError { underlying: String, }, CreateEmailError { underlying: String, }, AddAttachmentsError { underlying: String, }, SendEmailError { underlying: String, }, InvalidDecimalToF64Conversion { value: String, }, InvalidDecimalFromF64Conversion { value: f64, }, FailedToLoadFont { family_name: String, }, InvalidF64String { bad_value: String, reason: String, }, FailedToWriteDataToDisk { underlying: String, }, FailedToRonSerializeData { type_name: String, underlying: String, }, InvalidCompanyInformation { reason: String, }, InvalidInvoiceNumberString { invalid_string: String, }, InvalidInvoiceInfo { reason: String, }, InvalidPaymentInfo { reason: String, }, InvalidServiceFees { reason: String, }, OffsetPeriodMustNotBeInRecordOfPeriodsOff { offset_period: String, period_kind: String, }, SpecifiedOutputPathDoesNotExist { path: String, }, FailedToCreateOutputDirectory { underlying: String, }, TargetPeriodMustHaveExpenses { target_period: String, }, FailedToParseYear { invalid_string: String, }, FileNotFound { path: String, underlying: String, }, Deserialize { type_name: String, error: String, }, InvalidDayFromString { invalid_string: String, reason: String, }, InvalidYearAndMonth { underlying: String, }, InvalidDate { underlying: String, }, InvalidDay { day: i32, reason: String, }, InvalidMonth { month: i32, reason: String, }, FailedToParseMonth { invalid_string: String, }, InvalidExpenseItem { invalid_string: String, reason: String, }, TargetPeriodMustNotBeInRecordOfPeriodsOff { target_period: String, }, FailedToParsePaymentTermsNetDays { invalid_string: String, }, L18nNotFound { language: Language, }, InvalidHexColor { invalid_string: String, }, FailedToParseDate { underlying: String, }, FoundNoExchangeRate { target: Currency, base: Currency, }, LoadSource { underlying: String, }, BuildPdf { underlying: String, }, ExportDocumentToPdf { underlying: String, }, SavePdf { underlying: String, }, NetworkError { underlying: String, }, ParseError { underlying: String, },
}
Error type for the logic crate, encapsulating various errors that can occur during PDF generation and manipulation.

Variants



RecordsOffMustNotContainOffsetPeriod

The offset period must not be in the record of periods off.

Fields

offset_period: String


StartPeriodAfterEndPeriod

The start period is after the end period.

Fields

start: String


InvalidPeriod

Not a valid YearAndMonth nor YearMonthAndFortnight

Fields

bad_value: String


PeriodIsNotYearAndMonth

Period is not YearAndMonth



PeriodIsNotYearMonthAndFortnight

Period is not YearMonthAndFortnight



InvalidGranularityForTimeOff

Fields

free_granularity: Granularity
service_fees_granularity: Granularity


GranularityTooCoarse

Granularity too coarse,

Fields

granularity: Granularity
max_granularity: Granularity
target_period: String


CannotInvoiceForMonthWhenCadenceIsBiWeekly

Cannot invoice for month when cadence is bi-weekly.



CannotExpenseForMonthWhenCadenceIsBiWeekly

Cannot expense for month when cadence is bi-weekly



CannotExpenseForFortnightWhenCadenceIsMonthly

Cannot expense for fortnight when cadence is monthly.



PasswordDoesNotMatch

Password does not match, e.g. when the user tries to set a password and the confirmation password does not match.



EmailPasswordTooShort

Email password is too short.

Fields

min_length: usize

The minimum length of the email password.

actual_length: usize

The actual length of the email password.



EmailAtomTemplateError

Failed to parse the email atom template, e.g. when the template is not valid.

Fields

underlying: String


InvalidEmailAddress

Invalid email address

Fields

role: String
underlying: String


InvalidNameForEmail

Invalid name for email

Fields

role: String
underlying: String


InvalidPasswordForEmail

Fields

purpose: String
underlying: String


RecipientAddressesCannotBeEmpty

Recipient addresses cannot be empty.



InvalidSmtpServer

Failed to parse SMTP Server

Fields

underlying: String


InvalidUtf8

Failed to parse a string into a valid UTF-8 string.



AESDecryptionFailed

Failed to decrypt data with AES.



InvalidAESBytesTooShort

Invalid AES bytes, e.g. when the length is not as expected.

Fields

expected_at_least: usize
found: usize


CreateSmtpTransportError

Failed to create SMTP transport, e.g. when the SMTP server is not reachable.

Fields

underlying: String


CreateEmailError

Failed to create Lettre Email from Email struct.

Fields

underlying: String


AddAttachmentsError

Failed to add attachments to the email, e.g. when the file is not found or cannot be read.

Fields

underlying: String

Underlying error when adding attachments to the email.



SendEmailError

Failed to send email

Fields

underlying: String


InvalidDecimalToF64Conversion

Failed to convert to f64 from a Decimal

Fields

value: String


InvalidDecimalFromF64Conversion

Failed to convert f64 value to a Decimal

Fields

value: f64


FailedToLoadFont

Failed to load a font, e.g. when the font file is not found or cannot be read.

Fields

family_name: String


InvalidF64String

Failed to parse a string into an Decimal, e.g. when the string is not a valid number.

Fields

bad_value: String
reason: String


FailedToWriteDataToDisk

Failed to write data to disk, e.g. when the file system is not accessible.

Fields

underlying: String


FailedToRonSerializeData

Failed to serialize data to RON format.

Fields

type_name: String
underlying: String


InvalidCompanyInformation

Error while building CompanyInformation from Terminal UI input.

Fields

reason: String


InvalidInvoiceNumberString

Failed to parse invoice number from a string, e.g. when the format is incorrect.

Fields

invalid_string: String


InvalidInvoiceInfo

Error while building InvoiceInfo from Terminal UI input.

Fields

reason: String


InvalidPaymentInfo

Error while building PaymentInfo from Terminal UI input.

Fields

reason: String


InvalidServiceFees

Error while building ServiceFees from Terminal UI input.

Fields

reason: String


OffsetPeriodMustNotBeInRecordOfPeriodsOff

The offset period must not be in the record of periods off.

Fields

offset_period: String
period_kind: String


SpecifiedOutputPathDoesNotExist

The manually specified output path does not exist.

Fields

path: String


FailedToCreateOutputDirectory

Failed to create the output directory for the PDF file.

Fields

underlying: String


TargetPeriodMustHaveExpenses

Target period must have expenses, but it does not.

Fields

target_period: String


FailedToParseYear

Failed to parse year

Fields

invalid_string: String


FileNotFound

Failed to load file

Fields

path: String
underlying: String


Deserialize

Failed to deserialize a type

Fields

type_name: String
error: String


InvalidDayFromString

Failed to parse Day from String

Fields

invalid_string: String
reason: String


InvalidYearAndMonth

Invalid YearAndMonth

Fields

underlying: String


InvalidDate

Invalid date

Fields

underlying: String


InvalidDay

Invalid day of the month, e.g. when the day is not between 1 and 31.

Fields

day: i32
reason: String


InvalidMonth

Invalid month, e.g. when the month is not between 1 and 12.

Fields

month: i32
reason: String


FailedToParseMonth

Failed to parse Month from String

Fields

invalid_string: String


InvalidExpenseItem

Failed to parse expense item from a string, e.g. when the format is incorrect.

Fields

invalid_string: String
reason: String


TargetPeriodMustNotBeInRecordOfPeriodsOff

The target period is in the record of periods off, but it must not be.

Fields

target_period: String


FailedToParsePaymentTermsNetDays

Failed to parse PaymentTerms NetDays from a string, e.g. when the format is incorrect.

Fields

invalid_string: String


L18nNotFound

Failed to find the localization file for a specific language.

Fields

language: Language

The language that was not found, e.g. “EN” for English.



InvalidHexColor

Failed to parse a string into a Hexcolor

Fields

invalid_string: String


FailedToParseDate

Failed to parse a date, e.g. when the format is incorrect or the date is invalid.

Fields

underlying: String


FoundNoExchangeRate

Error converting between currencies, e.g. when the exchange rate is not found.

Fields

target: Currency

The target currency for the exchange rate, e.g. “EUR”.

base: Currency

The base currency for the exchange rate, e.g. “USD”.



LoadSource

Error when loading a resource for typst.

Fields

underlying: String


BuildPdf

Error when compiling Typst source to a PagedDocument.

Fields

underlying: String


ExportDocumentToPdf

Error when exporting a PagedDocument to PDF.

Fields

underlying: String


SavePdf

Error when saving the PDF to a file.

Fields

underlying: String


NetworkError

Error when fetching exchange rates from an API.

Fields

underlying: String


ParseError

Error when parsing the response from the exchange rate API.

Fields

underlying: String