pub struct Data<Period>where
Period: IsPeriod,{ /* private fields */ }Expand description
The input data for the invoice, which includes information about the invoice, the vendor, and the client and the products/services included in the invoice.
Implementations
Sourceimpl<Period> Data<Period>where
Period: IsPeriod,
impl<Period> Data<Period>where
Period: IsPeriod,
Sourcepub fn builder() -> DataBuilder<Period>
pub fn builder() -> DataBuilder<Period>
Create an instance of Data using the builder syntax
Sourceimpl<Period> Data<Period>where
Period: IsPeriod,
impl<Period> Data<Period>where
Period: IsPeriod,
Sourcepub fn information(&self) -> &ProtoInvoiceInfo<Period>
pub fn information(&self) -> &ProtoInvoiceInfo<Period>
Information about this specific invoice.
Sourcepub fn vendor(&self) -> &CompanyInformation
pub fn vendor(&self) -> &CompanyInformation
The company that issued the invoice, the vendor/seller/supplier/issuer.
Sourcepub fn client(&self) -> &CompanyInformation
pub fn client(&self) -> &CompanyInformation
The company that pays the invoice, the customer/buyer.
Sourcepub fn payment_info(&self) -> &PaymentInformation
pub fn payment_info(&self) -> &PaymentInformation
Payment information for the vendor, used for international transfers. This includes the IBAN, bank name, and BIC. This is used to ensure that the client can pay the invoice correctly.
Sourcepub fn service_fees(&self) -> &ServiceFees
pub fn service_fees(&self) -> &ServiceFees
Price of service, if applicable.
Sourcepub fn expensed_periods(&self) -> &ExpensedPeriods<Period>
pub fn expensed_periods(&self) -> &ExpensedPeriods<Period>
Any expenses that you might have incurred.
Sourceimpl<Period> Data<Period>where
Period: IsPeriod,
impl<Period> Data<Period>where
Period: IsPeriod,
Sourcepub fn with_client(self, val: CompanyInformation) -> Data<Period>
pub fn with_client(self, val: CompanyInformation) -> Data<Period>
The company that pays the invoice, the customer/buyer.
Sourceimpl<Period> Data<Period>where
Period: IsPeriod,
impl<Period> Data<Period>where
Period: IsPeriod,
Sourcepub fn set_expensed_periods(
&mut self,
val: ExpensedPeriods<Period>,
) -> &mut Data<Period>
pub fn set_expensed_periods( &mut self, val: ExpensedPeriods<Period>, ) -> &mut Data<Period>
Any expenses that you might have incurred.
Sourceimpl<Period> Data<Period>where
Period: IsPeriod,
impl<Period> Data<Period>where
Period: IsPeriod,
Sourcepub fn validate(self) -> Result<Data<Period>, Error>
pub fn validate(self) -> Result<Data<Period>, Error>
Validates the invoice information and returns a Result<Self>.
If the information is valid, it returns Ok(self).
If the information is invalid
it returns an Error with the validation error.
Errors
Returns an error if the invoice information is invalid.
Examples
extern crate klirr_core;
use klirr_core::prelude::*;
let data = Data::<YearAndMonth>::sample();
let result = data.validate();
assert!(result.is_ok(), "Expected validation to succeed, got: {:?}", result);Sourcepub fn to_partial(
self,
input: ValidInput,
) -> Result<DataFromDiskWithItemsOfKind<LineItemsPricedInSourceCurrency>, Error>
pub fn to_partial( self, input: ValidInput, ) -> Result<DataFromDiskWithItemsOfKind<LineItemsPricedInSourceCurrency>, Error>
Converts the Data into a DataWithItemsPricedInSourceCurrency
using the provided ValidInput.
This method prepares the invoice data for rendering by creating an
InvoiceInfoFull and populating it with the necessary information.
It also calculates the invoice date, due date, and prepares the output path.
Errors
Returns an error if the month is invalid or if there are issues with retrieving expenses for the month.
Examples
extern crate klirr_core;
use klirr_core::prelude::*;
let data = Data::<YearAndMonth>::sample();
let input = ValidInput::sample();
let result = data.to_partial(input);
assert!(result.is_ok(), "Expected conversion to succeed, got: {:?}", result);Trait Implementations
Sourceimpl<'de, Period> Deserialize<'de> for Data<Period>where
Period: IsPeriod + Deserialize<'de>,
impl<'de, Period> Deserialize<'de> for Data<Period>where
Period: IsPeriod + Deserialize<'de>,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<Data<Period>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<Data<Period>, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Sourceimpl<Period> PartialEq for Data<Period>
impl<Period> PartialEq for Data<Period>
Sourceimpl<Period> Serialize for Data<Period>
impl<Period> Serialize for Data<Period>
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
impl<Period> StructuralPartialEq for Data<Period>where
Period: IsPeriod,